==> at.bestsolution.rsd.rt.rs.resteasy-1.0.0-20210525.192032-4-sources.jar: at/bestsolution/rsd/rt/rs/resteasy/MultiPartUtil.java <==
package at.bestsolution.rsd.rt.rs.resteasy;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Map;
import java.util.function.Function;

import org.jboss.resteasy.plugins.providers.multipart.InputPart;

import at.bestsolution.rsd.rt.FileStream;

public class MultiPartUtil {
	public static String extractParameter( Map<String, List<InputPart>> data, String parameterName ) {
		List<InputPart> parts = data.get( parameterName );
		if( parts != null && ! parts.isEmpty() ) {
			try {
				return parts.get(0).getBodyAsString();
			} catch (IOException e) {
				throw new IllegalStateException( e );
			}
		}
		return null;
	}

	public static <T> T extractParameter( Map<String, List<InputPart>> data, String parameterName, Function<String,T> converter ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? null : converter.apply( rv );
	}
	
	public static int extractIntParameter( Map<String, List<InputPart>> data, String parameterName ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? 0 : Integer.parseInt( rv );
	}
	
	public static double extractDoubleParameter( Map<String, List<InputPart>> data, String parameterName ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? 0 : Double.parseDouble( rv );
	}
	
	public static long extractLongParameter( Map<String, List<InputPart>> data, String parameterName ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? 0 : Long.parseLong( rv );
	}
	
	public static boolean extractBooleanParameter( Map<String, List<InputPart>> data, String parameterName ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? false : Boolean.parseBoolean( rv );
	}

	public static FileStream extractStreamParameter( Map<String, List<InputPart>> data, String parameterName ) {
		List<InputPart> parts = data.get( parameterName );
		if( parts != null && !parts.isEmpty() ) {
			InputPart inputPart = parts.get( 0 );
			InputStream stream;
			try {
				stream = inputPart.getBody( InputStream.class, null );
			} catch( IOException e ) {
				throw new IllegalStateException( e );
			}

			String contentHeader = inputPart.getHeaders().getFirst( "Content-Disposition" );

			if( contentHeader != null ) {
				for( String item : contentHeader.split( ";" ) ) {
					if( item.trim().startsWith( "filename" ) ) {
						String val = item.substring( item.indexOf( '=' ) + 1 ).trim();
						if( val.startsWith( "\"" ) ) {
							val = val.substring( 1 );
						}
						if( val.endsWith( "\"" ) ) {
							val = val.substring( 0, val.length() - 1 );
						}
						return FileStream.from( stream, val );
					}
				}
			}
		}
		return null;
	}
}

==> at.bestsolution.rsd.rt.rs.resteasy-1.0.0-20210722.104722-10-sources.jar: at/bestsolution/rsd/rt/rs/resteasy/MultiPartUtil.java <==
package at.bestsolution.rsd.rt.rs.resteasy;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Map;
import java.util.function.Function;

import org.jboss.resteasy.plugins.providers.multipart.InputPart;

import at.bestsolution.rsd.rt.FileStream;

public class MultiPartUtil {
	public static String extractParameter( Map<String, List<InputPart>> data, String parameterName ) {
		List<InputPart> parts = data.get( parameterName );
		if( parts != null && ! parts.isEmpty() ) {
			try {
				return parts.get(0).getBodyAsString();
			} catch (IOException e) {
				throw new IllegalStateException( e );
			}
		}
		return null;
	}

	public static <T> T extractParameter( Map<String, List<InputPart>> data, String parameterName, Function<String,T> converter ) {
		return extractParameter( data, parameterName, converter, null );
	}
	
	public static <T> T extractParameter( Map<String, List<InputPart>> data, String parameterName, Function<String,T> converter, T defaultValue ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? defaultValue : converter.apply( rv );
	}
	
	public static int extractIntParameter( Map<String, List<InputPart>> data, String parameterName ) {
		return extractIntParameter( data, parameterName, 0 );
	}
	
	public static int extractIntParameter( Map<String, List<InputPart>> data, String parameterName, int defaultValue ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? defaultValue : Integer.parseInt( rv );
	}
	
	public static double extractDoubleParameter( Map<String, List<InputPart>> data, String parameterName ) {
		return extractDoubleParameter( data, parameterName, 0 );
	}
	
	public static double extractDoubleParameter( Map<String, List<InputPart>> data, String parameterName, double defaultValue ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? defaultValue : Double.parseDouble( rv );
	}
	
	public static long extractLongParameter( Map<String, List<InputPart>> data, String parameterName ) {
		return extractLongParameter( data, parameterName, 0 );
	}
	
	public static long extractLongParameter( Map<String, List<InputPart>> data, String parameterName, long defaultValue ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? defaultValue : Long.parseLong( rv );
	}
	
	public static boolean extractBooleanParameter( Map<String, List<InputPart>> data, String parameterName ) {
		return extractBooleanParameter( data, parameterName, false );
	}
	
	public static boolean extractBooleanParameter( Map<String, List<InputPart>> data, String parameterName, boolean defaultValue ) {
		String rv = extractParameter( data, parameterName );
		return rv == null ? defaultValue : Boolean.parseBoolean( rv );
	}

	public static FileStream extractStreamParameter( Map<String, List<InputPart>> data, String parameterName ) {
		List<InputPart> parts = data.get( parameterName );
		if( parts != null && !parts.isEmpty() ) {
			InputPart inputPart = parts.get( 0 );
			InputStream stream;
			try {
				stream = inputPart.getBody( InputStream.class, null );
			} catch( IOException e ) {
				throw new IllegalStateException( e );
			}

			String contentHeader = inputPart.getHeaders().getFirst( "Content-Disposition" );

			if( contentHeader != null ) {
				for( String item : contentHeader.split( ";" ) ) {
					if( item.trim().startsWith( "filename" ) ) {
						String val = item.substring( item.indexOf( '=' ) + 1 ).trim();
						if( val.startsWith( "\"" ) ) {
							val = val.substring( 1 );
						}
						if( val.endsWith( "\"" ) ) {
							val = val.substring( 0, val.length() - 1 );
						}
						return FileStream.from( stream, val );
					}
				}
			}
		}
		return null;
	}
}
